from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy import Table, Column, ForeignKey, text, func
from sqlalchemy.types import *
from sqlalchemy.orm import relation, sessionmaker
from sqlalchemy.orm.interfaces import SessionExtension

Base = declarative_base()
Base.metadata.bind = 'sqlite://'

class User(Base):
    __tablename__ = 'user'
    id = Column(Integer, primary_key=True)
    username = Column(String(20))

class Ticket(Base):
    __tablename__ = 'ticket'
    id = Column(Integer, primary_key=True)
    assigned_to_id = Column(ForeignKey(User.id))

    assigned_to = relation(User, primaryjoin = assigned_to_id ==
User.id,
                            lazy=True)

class SKSessionExtension(SessionExtension):
    def after_flush(self, session, flush_context):
        """
        implement the after-flush signal
        """

        for new in session.new:
            if isinstance(new, Ticket):
                print "NEW: %s - assigned_to: %s" % ( new,
new.assigned_to)

Session = sessionmaker(bind=Base.metadata.bind)
session = Session(extension=SKSessionExtension())

Base.metadata.create_all()
#Base.metadata.bind.echo = True

user = User()
user.username = 'aaa'
session.add(user)
session.commit()

ticket = Ticket()
ticket.assigned_to_id = user.id

session.add(ticket)

session.flush()

print "AFTER FLUSH", ticket.assigned_to

session.commit()

print "AFTER COMMIT", ticket.assigned_to 
